@@ -18,6 +18,7 @@ import functools
 import zipfile
 import xlsxwriter
 from typing import Any, List, Union, NoReturn, Set, Type, Iterator, Callable
+from numpy import ndarray
 from aitool.basic_function.basic import split_dict
 from aitool.basic_function.deduplication import Deduplication
 
@@ -320,7 +321,7 @@ def load_lines(
         separator_time: int = -1,
         form: str = None,
         deduplication: bool = False,
-) -> List[Any]:
+) -> Union[list, dict, set]:
     data = []
     cache = Deduplication()
     with open(file, 'r', encoding='utf8') as fin:
@@ -340,7 +341,7 @@ def load_lines(
         print('dict格式用每行的第一个元素作为key, 其后的元素的列表作为value。'
               '如果一行中不包含多个元素会报错。'
               '如果有相同的第一个元素会发生覆盖。')
-        data = {item[0]: item[1:] for item in data}
+        data = {item[0]: item[1:] if len(item) > 2 else item[1] for item in data}
     return data
 
 
@@ -407,13 +408,18 @@ dump_csv = functools.partial(dump_panda, file_format='csv')
 dump_excel = functools.partial(dump_panda, file_format='excel')
 
 
-def load_excel(*args, **kwargs) -> List:
+def load_excel(to_list=False, *args, **kwargs) -> Union[ndarray, Any]:
+    kwargs['engine'] = 'openpyxl' if 'engine' not in kwargs else kwargs['engine']
+    kwargs['keep_default_na'] = False if 'keep_default_na' not in kwargs else kwargs['keep_default_na']
+
     data = np.array([])
     try:
         df = pd.read_excel(*args, **kwargs)
         data = df.values
     except ValueError as err:
         print(err)
+    if to_list:
+        return data.tolist()
     return data
 
 
